FloatingTabBar class

Inheritance

Constructors

FloatingTabBar({Key? key, required List<TabItem> children, AppBar? parentAppbar, double? minExtendedWidth = 200, bool? useIndicator, Widget? leading, Color? indicatorColor, Color? activeColor, Color? inactiveColor, Color? backgroundColor, bool? isFloating = true, bool? useNautics = false, bool? showTabLabelsForNonFloating = false, bool? showTabLabelsForFloating = false, bool? smallScreenMode, Widget? nauticsFooter})
const

Properties

activeColor → Color?
Widget activeColor color, default : primary color
final
backgroundColor → Color?
Widget backgroundColor color, default : Colors.transparent
final
children → List<TabItem>
List of "TabItem" which will be shown on naigation bar
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveColor → Color?
Widget inactiveColor color, default : primary color
final
indicatorColor → Color?
Widget indicator color shows a circle around widget, default : Colors.transparent
final
isFloating → bool?
The default value "true" will show floating TabBar, "false" value will show normal bottom navigation bar
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
Leading widget that will on top of sidebar on Navigation rail.
final
minExtendedWidth → double?
Minimum extension width for NavigationRail which is used in large screens.
final
nauticsFooter → Widget?
Footer widget for nautics sidebar widget, this will be shown when 'useNautics = true'
final
parentAppbar → AppBar?
A "AppBar?" widget that will be shown to all the platforms which has true boolean value as top appbar.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showTabLabelsForFloating → bool?
Shows Labels for Floating type
final
showTabLabelsForNonFloating → bool?
Shows Labels for Non-Floating type
final
smallScreenMode → bool?
Force the widget to be in small screen mode
final
useIndicator → bool?
Indicator around the widget
final
useNautics → bool?
Use Nautics sidebar instead of navigation rail for large screens when true, default values from FloatingTabbar will be dispayed in Nautics.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FloatingTabBarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited