TabItem class

Constructors

TabItem({required Widget title, required void onTap()?, bool tIOnTap = false, Widget? subTitle, Widget? selectedLeading, Widget? unSelectedLeading, Widget? trailing, Widget? tab, int? badgeCount = 0, List<TabItem>? children = const [], Color? color, bool? enabled, dynamic isSelected(bool)?})
const

Properties

badgeCount → int?
Will show a badge count on top of TabItem, when a positive value is provided.
final
children → List<TabItem>?
Children of the current TabItem.
final
color → Color?
Color associated with TabItem.
final
enabled → bool?
To enable or disable tabitem.
final
hashCode → int
The hash code for this object.
no setterinherited
isSelected → dynamic Function(bool)?
Boolean to indicate the specific tabItem is selected or visited.
final
onTap → void Function()?
Callback spicific to the TabItem.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedLeading → Widget?
Will show for leading selected icon
final
subTitle → Widget?
SubTitle for the tabItem
final
tab → Widget?
The widget corresponding to the tab item
final
tIOnTap → bool
With true value the function provided for onTap will be called when clicked on the tab, if false, either default or anonymous function is called.
final
title → Widget
Title for the tabItem
final
trailing → Widget?
Trailing widget for the tabItem
final
unSelectedLeading → Widget?
Will show for un-leading unselected icon
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited