Header class

Inheritance

Constructors

Header({Key? key, required List<TabItem> children, Widget? leading, Widget? trailing, bool showLeading = true, bool showTrailing = true, MainAxisAlignment alignment = MainAxisAlignment.center, required String title, double? height, bool isFloating = true})
const

Properties

alignment → MainAxisAlignment
MainAxisAlignment for the tabs on the large screen.
final
children → List<TabItem>
List of TabItem
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
Height of Header
final
isFloating → bool
Boolean that enables or disables the floating interface of the tabs in Header.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
leading will be seen as leading widget on small screen as header in drawer when using default.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showLeading → bool
when true will show leading icon for the children tabs
final
showTrailing → bool
when true will show trailing icon for the children tabs
final
title → String
Title of the landing page
final
trailing → Widget?
trailing will be seen as trailing widget on small screen as footer in drawer when using default.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<Header>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited